@@ -29,8 +29,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman at xael.org)'
-__version__ = '0.3.1'
-__last_modification__ = '2015.01.10'
+__version__ = '0.3.7'
+__last_modification__ = '2015.01.12'
 
 import datetime
 import logging
@@ -94,7 +94,10 @@ def add_vacations(start_date, end_date=None):
 
 def init_log_to_sysout(level=logging.INFO):
     """
-    debugging facilities
+    Init global variable __LOG__ used for logging purpose
+
+    Keyword arguments:
+    level -- logging level (from logging.debug to logging.critical)
     """
     global __LOG__
     logger = logging.getLogger("Gantt")
@@ -295,6 +298,24 @@ class GroupOfResources(object):
         return overcharged_days
 
 
+
+    def is_vacant(self, from_date, to_date):
+        """
+        Check if any resource from the group is unallocated between for a given timeframe.
+        Returns a list of available ressource name.
+        
+        Keyword arguments:
+        from_date -- first day
+        to_date --  last day
+        """
+        availables = []
+        for r in self.resources:
+            if len(r.is_vacant(from_date, to_date)) >0:
+                availables.append(r.name)
+                
+        return availables
+
+
 ############################################################################
 
 class Resource(object):
@@ -440,6 +461,29 @@ class Resource(object):
             
 
 
+    def is_vacant(self, from_date, to_date):
+        """
+        Check if the resource is unallocated between for a given timeframe.
+        Returns True if the resource is free, False otherwise
+        
+        Keyword arguments:
+        from_date -- first day
+        to_date --  last day
+        """
+        non_vacant_days = self.search_for_task_conflicts(all_tasks=True)
+        cday = from_date
+        while cday <= to_date:
+            if cday.weekday() not in NOT_WORKED_DAYS:
+                if not self.is_available(cday):
+                    __LOG__.debug('** Ressource "{0}" is not available on day {1} (vacation)'.format(self.name, cday))
+                    return []
+                if cday in non_vacant_days:
+                    __LOG__.debug('** Ressource "{0}" is not available on day {1} (other task : {2})'.format(self.name, cday, non_vacant_days[cday]))
+                    return []
+
+            cday += datetime.timedelta(days=1)
+        return [self.name]
+
 ############################################################################
 
 
@@ -1045,10 +1089,10 @@ class Project(object):
 
         vlines = dwg.add(svgwrite.container.Group(id='vlines', stroke='lightgray'))
         for x in range(maxx):
-            vlines.add(svgwrite.shapes.Line(start=(x*cm, 1*cm), end=(x*cm, (maxy+1)*cm)))
+            vlines.add(svgwrite.shapes.Line(start=(x*cm, 2*cm), end=(x*cm, (maxy+2)*cm)))
             if (start_date + datetime.timedelta(days=x)).weekday() in NOT_WORKED_DAYS or (start_date + datetime.timedelta(days=x)) in VACATIONS:
                 vlines.add(svgwrite.shapes.Rect(
-                    insert=(x*cm, 1*cm),
+                    insert=(x*cm, 2*cm),
                     size=(1*cm, maxy*cm),
                     fill='gray',
                     stroke='lightgray',
@@ -1058,34 +1102,43 @@ class Project(object):
             jour = start_date + datetime.timedelta(days=x)
             if not today is None and today == jour:
                 vlines.add(svgwrite.shapes.Rect(
-                    insert=((x+0.4)*cm, 0.5*cm),
-                    size=(0.2*cm, (0.5+maxy)*cm),
-                    fill='lightblue',
+                    insert=((x+0.4)*cm, 2*cm),
+                    size=(0.2*cm, (maxy)*cm),
+                    fill='#76e9ff',
                     stroke='lightgray',
                     stroke_width=0,
                     opacity=0.8
                     ))
-            vlines.add(svgwrite.text.Text('{2}.{0:02}/{1:02}'.format(jour.day, jour.month, cal[jour.weekday()][0]), insert=((x*10+1)*mm, 9*mm), fill='black', stroke='black', stroke_width=0, font_family="Verdana", font_size="8"))
+            #vlines.add(svgwrite.text.Text('{2}.{0:02}/{1:02}'.format(jour.day, jour.month, cal[jour.weekday()][0]), insert=((x*10+1)*mm, 9*mm), fill='black', stroke='black', stroke_width=0, font_family="Verdana", font_size="8"))
 
-            daytext = []
+            # Current day
+            vlines.add(svgwrite.text.Text('{1} {0:02}'.format(jour.day, cal[jour.weekday()][0]), insert=((x*10+1)*mm, 19*mm), fill='black', stroke='black', stroke_width=0, font_family="Verdana", font_size="12"))
 
+
+            # Year
             if jour.day == 1 and jour.month == 1:
-                vlines.add(svgwrite.text.Text('{0}'.format(jour.year), insert=((x*10+1)*mm, 3*mm), fill='#800000', stroke='#800000', stroke_width=0, font_family="Verdana", font_size="12"))
-            
-            if jour.weekday() == 0:
-                daytext.append('W:{0:02}'.format(jour.isocalendar()[1]))
+                vlines.add(svgwrite.text.Text('{0}'.format(jour.year), insert=((x*10+1)*mm, 5*mm), fill='#400000', stroke='#400000', stroke_width=0, font_family="Verdana", font_size="20", font_weight="bold"))
 
+
+            # Month name
             if jour.day == 1:
-                daytext.append('{0}'.format(jour.strftime("%B")[:3]))
+                #daytext.append('{0}'.format(jour.strftime("%B")[:3]))
+                vlines.add(svgwrite.text.Text('{0}'.format(jour.strftime("%B")), insert=((x*10+1)*mm, 10*mm), fill='#800000', stroke='#800000', stroke_width=0, font_family="Verdana", font_size="18", font_weight="bold"))
 
-            if len(daytext) > 0:
-                vlines.add(svgwrite.text.Text(' / '.join(daytext), insert=((x*10+1)*mm, 6*mm), fill='black', stroke='black', stroke_width=0, font_family="Verdana", font_size="12"))
+
+            # Week number
+            if jour.weekday() == 0:
+                vlines.add(svgwrite.text.Text('{0:02}'.format(jour.isocalendar()[1]), insert=((x*10+1)*mm, 15*mm), fill='black', stroke='black', stroke_width=0, font_family="Verdana", font_size="16", font_weight="bold"))
 
         vlines.add(svgwrite.shapes.Line(start=(maxx*cm, 1*cm), end=(maxx*cm, (maxy+1)*cm)))
 
 
         hlines = dwg.add(svgwrite.container.Group(id='hlines', stroke='lightgray'))
-        for y in range(1, maxy+2):
+
+        dwg.add(svgwrite.shapes.Line(start=((0)*cm, (2)*cm), end=((maxx+1)*cm, (2)*cm), stroke='black'))
+        dwg.add(svgwrite.shapes.Line(start=((0)*cm, (maxy+2)*cm), end=((maxx+1)*cm, (maxy+2)*cm), stroke='black'))
+
+        for y in range(2, maxy+3):
             hlines.add(svgwrite.shapes.Line(start=(0*cm, y*cm), end=(maxx*cm, y*cm)))
 
         return dwg
@@ -1128,7 +1181,7 @@ class Project(object):
 
         ldwg = svgwrite.container.Group()
     
-        psvg, pheight = self.svg(prev_y=1, start=start_date, end=end_date, color = self.color)
+        psvg, pheight = self.svg(prev_y=2, start=start_date, end=end_date, color = self.color)
         ldwg.add(psvg)
         dep = self.svg_dependencies(self)
         if dep is not None:
@@ -1137,7 +1190,7 @@ class Project(object):
         dwg = svgwrite.Drawing(filename, debug=True)
         dwg.add(svgwrite.shapes.Rect(
                     insert=(0*cm, 0*cm),
-                    size=((maxx+1)*cm, (pheight+1)*cm),
+                    size=((maxx+1)*cm, (pheight+3)*cm),
                     fill='white',
                     stroke_width=0,
                     opacity=1
@@ -1208,8 +1261,17 @@ class Project(object):
 
 
         ldwg = svgwrite.container.Group()
+
+        if not one_line_for_tasks:
+            ldwg.add(
+                svgwrite.shapes.Line(
+                    start=((0)*cm, (2)*cm), 
+                    end=((maxx+1)*cm, (2)*cm), 
+                    stroke='black',
+                    ))
+
     
-        nline = 1
+        nline = 2
         conflicts_tasks = []
         conflict_display_line = 1
         for r in resources:
@@ -1281,12 +1343,12 @@ class Project(object):
         dwg = svgwrite.Drawing(filename, debug=True)
         dwg.add(svgwrite.shapes.Rect(
                     insert=(0*cm, 0*cm),
-                    size=((maxx+1)*cm, (nline)*cm),
+                    size=((maxx+1)*cm, (nline+1)*cm),
                     fill='white',
                     stroke_width=0,
                     opacity=1
                     ))
-        dwg.add(self._svg_calendar(maxx, nline-1, start_date, today))
+        dwg.add(self._svg_calendar(maxx, nline-2, start_date, today))
         dwg.add(ldwg)
         dwg.save()
         return {
